<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Delete_Customers extends WP_List_Table {
	/** Class constructor */
    
	public function __construct() {
		parent::__construct( [
			'singular' => __( 'Customer', 'wpmyownsms' ), //singular name of the listed records
			'plural'   => __( 'Customers', 'wpmyownsms' ), //plural name of the listed records
			'ajax'     => false //does this table support ajax?
		] );
	}

	/**
	 * Retrieve customers data from the database
	 *
	 * @param int $per_page
	 * @param int $page_number
	 *
	 * @return mixed
	 */
	public static function get_customers( $per_page = 5, $page_number = 1 ) {
		global $wpdb;
        
        $do_search = MyOwn_Delete_Customers::query_search();
        
        $sql = "SELECT * ". 
            "FROM {$wpdb->prefix}myownsms_woo_customers " .
            "RIGHT JOIN {$wpdb->prefix}myownsms_subscriber ON {$wpdb->prefix}myownsms_woo_customers.user_id = {$wpdb->prefix}myownsms_subscriber.id_address " . 
            "WHERE {$wpdb->prefix}myownsms_subscriber.id_status = 1 " .
            $do_search;
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;
        
        $result = $wpdb->get_results( $sql, 'ARRAY_A' );
        return $result;
	}
        
        private static function query_search(){
        global $wpdb;
        
        $search = filter_input( INPUT_POST, 's', FILTER_SANITIZE_STRING );
        $search_select = filter_input( INPUT_POST, 'page', FILTER_SANITIZE_STRING );
        if ( $search && $search_select = 'delete_customers' ) {
            $do_search = $wpdb->prepare(" AND ( {$wpdb->prefix}myownsms_woo_customers.billing_first_name LIKE '%%%s%%' ", $search ); 
            $do_search .= " OR " .$wpdb->prepare(" {$wpdb->prefix}myownsms_woo_customers.billing_last_name LIKE '%%%s%%' ", $search ); 
            $do_search .= " OR " .$wpdb->prepare(" {$wpdb->prefix}myownsms_woo_customers.billing_postcode LIKE '%%%s%%' ", $search ); 
            $do_search .= " OR " .$wpdb->prepare(" {$wpdb->prefix}myownsms_woo_customers.billing_country LIKE '%%%s%%' ", $search ); 
            $do_search .= " OR " .$wpdb->prepare(" {$wpdb->prefix}myownsms_woo_customers.billing_address_1 LIKE '%%%s%%' )", $search );   
        }   else {
            $do_search = '';
        }
        return $do_search;
        }

	/**
	 * added a customer record.
	 *
	 * @param int $id customer ID
	 */
	public static function delete_customer( $id_address ) {
		global $wpdb;
        $wpdb->update( 
            "{$wpdb->prefix}myownsms_subscriber",
            array( 'id_status' => 0) , 
            array( 'id_address' => $id_address ), 
            array( '%d'	), 
            array( '%d' ) 
        );
	}

	/**
	 * Returns the count of records in the database.
	 *
	 * @return null|string
	 */
	public static function record_count() {
		global $wpdb;
                $do_search = MyOwn_Delete_Customers::query_search();
                $sql = "SELECT COUNT(*) ". 
                    "FROM {$wpdb->prefix}myownsms_woo_customers " .
                    "RIGHT JOIN {$wpdb->prefix}myownsms_subscriber ON {$wpdb->prefix}myownsms_woo_customers.user_id = {$wpdb->prefix}myownsms_subscriber.id_address " . 
                    "WHERE {$wpdb->prefix}myownsms_subscriber.id_status = 1 " .
                    $do_search;
                    
		return $wpdb->get_var( $sql );
	}

	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No customers avaliable.', 'wpmyownsms' );
	}

	/**
	 * Render a column when no column specific method exist.
	 *
	 * @param array $item
	 * @param string $column_name
	 *
	 * @return mixed
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'billing_first_name':
			case 'billing_last_name':
            case 'billing_address_1':
				return $item[ $column_name ];
			default:
                return $item[ $column_name ];
				//return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}

	/**
	 * Render the bulk edit checkbox
	 *
	 * @param array $item
	 *
	 * @return string
	 */
	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="bulk-delete-customer[]" value="%s" />', $item['user_id']
		);
	}

	/**
	 * Method for name column
	 *
	 * @param array $item an array of DB data
	 *
	 * @return string
	 */
	function column_name( $item ) {
		$select_nonce = wp_create_nonce( 'sp_delete_customer' );
		$title = '<strong>' . $item['user_id'] . '</strong>';
		$actions = [
			'delete' => sprintf( '<a href="?page=%s&action=%s&user_id=%s&_wpnonce=%s&tab=campaign">Delete</a>', 
                esc_attr( $_REQUEST['page'] ), 
                'delete', 
                absint( $item['user_id'] ), 
                $select_nonce )
		];
        
		return $title . $this->row_actions( $actions );
	}
    
    /**
	 * Method for name column
	 *
	 * @param array $item an array of DB data
	 *
	 * @return string
	 */
	function column_user_id( $item ) {
		$select_nonce = wp_create_nonce( 'sp_delete_customer' );
		$title = '<strong>' . $item['user_id'] . '</strong>';
		$actions = [
			'delete' => sprintf( '<a href="?page=%s&action=%s&user_id=%s&_wpnonce=%s&tab=campaign">Delete</a>', 
                esc_attr( $_REQUEST['page'] ), 
                'delete', 
                absint( $item['user_id'] ), 
                $select_nonce )
		];
        
		return $title . $this->row_actions( $actions );
	}

	/**
	 *  Associative array of columns
	 *
	 * @return array
	 */
	function get_columns() {
		$columns = [
			'cb'      => '<input type="checkbox" />',
			'user_id'    => __( 'ID', 'wpmyownsms' ),
			'billing_first_name' => __( 'First Name', 'wpmyownsms' ),
			'billing_last_name'    => __( 'Last Name', 'wpmyownsms' ),
            'billing_address_1' => __( 'Address', 'wpmyownsms' ),
			'billing_city'    => __( 'City', 'wpmyownsms' ),
            'billing_state' => __( 'State', 'wpmyownsms' ),
			'billing_postcode'    => __( 'Post Code', 'wpmyownsms' ),
            'billing_country'    => __( 'Country', 'wpmyownsms' ),
            'billing_email' => __( 'Email', 'wpmyownsms' ),
			'billing_phone'    => __( 'Phone', 'wpmyownsms' )
		];
		return $columns;
	}

	/**
	 * Returns an associative array containing the bulk action
	 *
	 * @return array
	 */
	public function get_bulk_actions() {
		$actions = [
			'bulk-delete-customer' => __('Delete','wpmyownsms')
		];
		return $actions;
	}

	/**
	 * Handles data query and filter, sorting, and pagination.
	 */
	public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
		$this->process_bulk_action();
		$per_page     = $this->get_items_per_page( 'customers_per_page', 5 );
		$current_page = $this->get_pagenum();
		$total_items  = self::record_count();
		$this->items = self::get_customers( $per_page, $current_page );
        $this->set_pagination_args( [
			'total_items' => $total_items,
			'per_page'    => $per_page,
            'total_pages' => ceil($total_items/$per_page)
		] );
	}

	public function process_bulk_action() {
        if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {
            $nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING );
            $action = 'bulk-' . $this->_args['plural'];
            if ( ! wp_verify_nonce( $nonce, $action ) )
                wp_die( 'Nope! Security check failed!' );
        }
        $action = $this->current_action();
        switch ( $action ) {
            case 'delete':
                self::delete_customer( absint( $_GET['user_id'] ) );
                wp_redirect( esc_url_raw('?page=myownsms_plg_configuration&tab=campaign') );
                break;
            case 'bulk-delete-customer':
                $delete_ids = esc_sql( $_POST['bulk-delete-customer'] );
                foreach ( $delete_ids as $id ) {
                    self::delete_customer( $id );
                }
                wp_redirect( esc_url_raw(add_query_arg()) );
                break;
            default:
                break;
        }
        return;
	}
}
