<?php
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WP_List_Table')) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Device_List extends WP_List_Table {

    /** Class constructor */
    public function __construct() {
        parent::__construct([
            'singular' => __('Device', 'wpmyownsms'), //singular name of the listed records
            'plural' => __('Devices', 'wpmyownsms'), //plural name of the listed records
            'ajax' => false //does this table support ajax?
        ]);
    }

    /**
     * Retrieve customers data from the database
     *
     * @param int $per_page
     * @param int $page_number
     *
     * @return mixed
     */
    public static function get_devices($per_page = 5, $page_number = 1) {
        global $wpdb;
        $sql = "SELECT * FROM {$wpdb->prefix}myownsms_devices WHERE state = 1";
        $result = $wpdb->get_results($sql, 'ARRAY_A');
        return $result;
    }

    /**
     * Delete a customer record.
     *
     * @param int $id customer ID
     */
    public static function delete_devices($id_device) {
        global $wpdb;
        $wpdb->update(
            "{$wpdb->prefix}myownsms_devices", array('state' => 2), array('id_device' => $id_device), array('%d'), array('%d')
        );
    }

    /**
     * Returns the count of records in the database.
     *
     * @return null|string
     */
    public static function record_count() {
        global $wpdb;
        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}myownsms_devices WHERE state = 1";
        return $wpdb->get_var($sql);
    }

    /** Text displayed when no customer data is available */
    public function no_items() {
        _e('No device avaliable.', 'wpmyownsms');
    }

    /**
     * Render a column when no column specific method exist.
     *
     * @param array $item
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default($item, $column_name) {
        switch ($column_name) {
            case 'id_device':
            case 'name_device':
            case 'num_tot_sms':
                return $item[$column_name];
            default:
                return print_r($item, true); //Show the whole array for troubleshooting purposes
        }
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb($item) {
        return sprintf(
            '<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['id_device']
        );
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_name($item) {
        $delete_nonce = wp_create_nonce('sp_delete_devices');
        $title = '<strong>' . $item['name_device'] . '</strong>';
        $actions = [
            'delete' => sprintf('<a href="?page=%s&action=%s&name_device=%s&_wpnonce=%s">Delete</a>', esc_attr($_REQUEST['page']), 'delete', absint($item['name_device']), $delete_nonce)
        ];

        return $title . $this->row_actions($actions);
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_id_device($item) {
        $delete_nonce = wp_create_nonce('sp_delete_devices');
        $title = '<strong>' . $item['id_device'] . '</strong>';
        $actions = [
            'delete' => sprintf('<a href="?page=%s&action=%s&id_device=%s&_wpnonce=%s">Delete</a>', esc_attr($_REQUEST['page']), 'delete', absint($item['id_device']), $delete_nonce)
        ];

        return $title . $this->row_actions($actions);
    }

    /**
     *  Associative array of columns
     *
     * @return array
     */
    function get_columns() {
        $columns = [
            'cb' => '<input type="checkbox" />',
            'id_device' => __('Device ID', 'wpmyownsms'),
            'name_device' => __('Device Name', 'wpmyownsms'),
            'num_tot_sms' => __('Total SMS sent', 'wpmyownsms')
        ];
        return $columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions() {
        $actions = [
            'bulk-delete' => __('Delete', 'wpmyownsms')
        ];
        return $actions;
    }

    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();
        $per_page = $this->get_items_per_page('customers_per_page', 5);
        $current_page = $this->get_pagenum();
        $total_items = self::record_count();
        //$data = array_slice($data,(($current_page-1)*$per_page),$per_page);
        $this->items = self::get_devices($per_page, $current_page);
        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ]);
    }

    public function process_bulk_action() {
        if (isset($_POST['_wpnonce']) && !empty($_POST['_wpnonce'])) {
            $nonce = filter_input(INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING);
            $action = 'bulk-' . $this->_args['plural'];
            if (!wp_verify_nonce($nonce, $action)) {
                //bo
            }
        }
        $action = $this->current_action();
        switch ($action) {
            case 'delete':
                self::delete_devices(absint($_GET['id_device']));
                wp_redirect(esc_url_raw('?page=myownsms_plg_configuration'));
                break;
            case 'bulk-delete':
                $delete_ids = esc_sql($_POST['bulk-delete']);
                // loop over the array of record IDs and delete them
                foreach ($delete_ids as $id) {
                    self::delete_devices($id);
                }
                wp_redirect(esc_url_raw(add_query_arg()));
                break;
            default:
                break;
        }
        return;
    }
}
