<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Campaign_History extends WP_List_Table {
	/** Class constructor */
    static private $type_state =
        array("00" => "Waiting", "01" => "Processing", "02" => "Completed", "03" => "Waiting");
    
	public function __construct() {
		parent::__construct( [
			'singular' => __( 'CampaignHistory', 'wpmyownsms' ), //singular name of the listed records
			'plural'   => __( 'CampaignsHistory', 'wpmyownsms' ), //plural name of the listed records
			'ajax'     => false
		] );
	}

	/**
	 * Retrieve customers data from the database
	 *
	 * @param int $per_page
	 * @param int $page_number
	 *
	 * @return mixed
	 */
	public static function get_history( $per_page = 5, $page_number = 1 ) {
		global $wpdb;
        
        $search = filter_input( INPUT_POST, 's', FILTER_SANITIZE_STRING );
        $search_select = filter_input( INPUT_POST, 'page', FILTER_SANITIZE_STRING );
        if ( $search && $search_select = 'campaign_history' ) {
            $do_search = $wpdb->prepare(" AND ( d.`name_device` LIKE '%%%s%%' ", $search );
            $do_search .= " OR " .$wpdb->prepare(" p.`name_campaign` LIKE '%%%s%%' ", $search ); 
            $do_search .= " OR " .$wpdb->prepare(" p.`message_sms` LIKE '%%%s%%' )", $search );     
        }   else {
            $do_search = '';
        }
        
        $sql = "SELECT p.* , d.`name_device` ". 
            "FROM {$wpdb->prefix}myownsms_polling AS p " .
            "INNER JOIN {$wpdb->prefix}myownsms_devices AS d ON p.id_device = d.id_device ".
            "WHERE ((p.`state` <> 00) AND (p.`state` <> 03)) ".
            "AND p.`recipient_id_customers` <> '' ".
            "AND name_campaign <> 'notification' ". $do_search ;
        
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;
        $result = $wpdb->get_results( $sql, 'ARRAY_A' );
        $_copy_customer = array();
        foreach ($result as $_c) {
            $_c['state'] = MyOwn_Campaign_History::$type_state[$_c['state']];
            $_copy_customer[] = $_c;
        }
        return $_copy_customer;
	}

	
	/**
	 * Returns the count of records in the database.
	 *
	 * @return null|string
	 */
	public static function record_count() {
		global $wpdb;
		$sql = "SELECT COUNT(*) FROM {$wpdb->prefix}myownsms_polling ".
            "WHERE ((`state` <> 00) AND (`state` <> 03)) ".
            "AND recipient_id_customers <> '' ".
            "AND name_campaign <> 'notification' ";
        return $wpdb->get_var( $sql );
	}

	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No history avaliable.', 'wpmyownsms' );
	}

	/**
	 * Render a column when no column specific method exist.
	 *
	 * @param array $item
	 * @param string $column_name
	 *
	 * @return mixed
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'name_device':
			case 'name_campaign':
            case 'message_sms':
				return $item[ $column_name ];
			default:
                return $item[ $column_name ];
		}
	}
	
	/**
	 *  Associative array of columns
	 *
	 * @return array
	 */
	function get_columns() {
		$columns = [
			'name_device'    => __( 'Device Name', 'wpmyownsms' ),
			'name_campaign'    => __( 'Campaign Title', 'wpmyownsms' ),
            'message_sms' => __( 'Message Text', 'wpmyownsms' ),
			'num_tot_recipient'    => __( 'Recipients Total', 'wpmyownsms' ),
            'date_begin' => __( 'Begin Date', 'wpmyownsms' ),
            'date_processing' => __( 'Process Date', 'wpmyownsms' ),
            'date_finish' => __( 'Finish Date', 'wpmyownsms' ),
            'state' => __( 'State', 'wpmyownsms' ),
		];
		return $columns;
	}

	/**
	 * Handles data query and filter, sorting, and pagination.
	 */
	public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
		$this->process_bulk_action();
		$per_page = 5;
		$current_page = $this->get_pagenum();
		$total_items  = self::record_count();
		$this->items = self::get_history( $per_page, $current_page );
        $this->set_pagination_args( [
			'total_items' => $total_items,
			'per_page'    => $per_page,
            'total_pages' => ceil($total_items/$per_page)
		] );
	}

}
