<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Campaign_Scheduled extends WP_List_Table {
	/** Class constructor */
    
	public function __construct() {
		parent::__construct( [
			'singular' => __( 'Campaign', 'wpmyownsms' ), //singular name of the listed records
			'plural'   => __( 'Campaigns', 'wpmyownsms' ), //plural name of the listed records
			'ajax'     => false //does this table support ajax?
		] );
	}

	/**
	 * Retrieve customers data from the database
	 *
	 * @param int $per_page
	 * @param int $page_number
	 *
	 * @return mixed
	 */
	public static function get_campaing_scheduled( $per_page = 5, $page_number = 1 ) {
		global $wpdb;
        
        $sql = "SELECT p.* , d.`name_device` ". 
            "FROM {$wpdb->prefix}myownsms_polling AS p " .
            "INNER JOIN {$wpdb->prefix}myownsms_devices AS d ON p.id_device = d.id_device ".
            "WHERE ((p.`state` = 00) OR (p.`state` = 03)) ".
            "AND recipient_id_customers <> '' ".
            "AND name_campaign <> 'notification'";
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;
        $result = $wpdb->get_results( $sql, 'ARRAY_A' );
        return $result;
	}

	/**
	 * added a customer record.
	 *
	 * @param int $id customer ID
	 */
	public static function remove_scheduled( $id_campaign ) {
		global $wpdb;
        $wpdb->delete( 
            "{$wpdb->prefix}myownsms_polling", 
            array( 'id_campaign' => $id_campaign , 'state' => '00'), 
            array( '%d', '%d' ) );
        $wpdb->show_errors();
	}

	/**
	 * Returns the count of records in the database.
	 *
	 * @return null|string
	 */
	public static function record_count() {
		global $wpdb;
		$sql = "SELECT COUNT(*) FROM {$wpdb->prefix}myownsms_polling ".
            "WHERE ((`state` = 00) OR (`state` = 03)) ".
            "AND recipient_id_customers <> '' ".
            "AND name_campaign <> 'notification'";
       
		return $wpdb->get_var( $sql );
	}

	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No campaign scheduled avaliable.', 'wpmyownsms' );
	}

	/**
	 * Render a column when no column specific method exist.
	 *
	 * @param array $item
	 * @param string $column_name
	 *
	 * @return mixed
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'id_campaign':
			case 'name_campaign':
            case 'message_sms':
				return $item[ $column_name ];
			default:
                return $item[ $column_name ];
		}
	}

	/**
	 * Render the bulk edit checkbox
	 *
	 * @param array $item
	 *
	 * @return string
	 */
	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="bulk-delete-campaign-scheduled[]" value="%s" />', $item['id_campaign']
		);
	}
    
    /**
	 * Method for name column
	 *
	 * @param array $item an array of DB data
	 *
	 * @return string
	 */
	function column_name_device( $item ) {
		$select_nonce = wp_create_nonce( 'sp_delete_campaign_scheduled' );
		$title = '<strong>' . $item['name_device'] . '</strong>';
		$actions = [
			'delete' => sprintf( '<a href="?page=%s&action=%s&id_campaign=%s&_wpnonce=%s&tab=history">Delete</a>', 
                esc_attr( $_REQUEST['page'] ), 
                'delete', 
                absint( $item['id_campaign'] ), 
                $select_nonce )
		];
        
		return $title . $this->row_actions( $actions );
	}

	/**
	 *  Associative array of columns
	 *
	 * @return array
	 */
	function get_columns() {
		$columns = [
			'cb'      => '<input type="checkbox" />',
			'name_device'    => __( 'Device Name', 'wpmyownsms' ),
			'name_campaign'    => __( 'Campaign Title', 'wpmyownsms' ),
            'message_sms' => __( 'Message Text', 'wpmyownsms' ),
			'num_tot_recipient'    => __( 'Recipients Total', 'wpmyownsms' ),
            'date_begin' => __( 'Begin Date', 'wpmyownsms' ),
		];
		return $columns;
	}
    
	/**
	 * Returns an associative array containing the bulk action
	 *
	 * @return array
	 */
	public function get_bulk_actions() {
		$actions = [
			'bulk-delete-campaign-scheduled' => __('Delete','wpmyownsms')
		];
		return $actions;
	}

	/**
	 * Handles data query and filter, sorting, and pagination.
	 */
	public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
		$this->process_bulk_action();
		$per_page     = $this->get_items_per_page( 'customers_per_page', 5 );
		$current_page = $this->get_pagenum();
		$total_items  = self::record_count();
		$this->items = self::get_campaing_scheduled( $per_page, $current_page );
        $this->set_pagination_args( [
			'total_items' => $total_items,
			'per_page'    => $per_page,
            'total_pages' => ceil($total_items/$per_page)
		] );
	}

	public function process_bulk_action() {
        if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {
            $nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING );
            $action = 'bulk-' . $this->_args['plural'];
            if ( ! wp_verify_nonce( $nonce, $action ) ){
                //wp_die( 'Nope! Security check failed!' );
            }
        }
        $action = $this->current_action();
        switch ( $action ) {
            case 'delete':
                self::remove_scheduled( absint( $_GET['id_campaign'] ) );
                wp_redirect( esc_url_raw('?page=myownsms_plg_configuration&tab=history') );
                break;
            case 'bulk-delete-campaign-scheduled':
                $delete_ids = esc_sql( $_POST['bulk-delete-campaign-scheduled'] );
                foreach ( $delete_ids as $id_campaign ) {
                    self::remove_scheduled( absint( $id_campaign ) );
                }
                wp_redirect( esc_url_raw(add_query_arg()) );
                break;
            default:
                break;
        }
        return;
	}
}
