<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Old_Device extends WP_List_Table {
	/** Class constructor */
    
	public function __construct() {
		parent::__construct( [
			'singular' => __( 'OldDevice', 'wpmyownsms' ), //singular name of the listed records
			'plural'   => __( 'OldDevices', 'wpmyownsms' ), //plural name of the listed records
			'ajax'     => false //does this table support ajax?
		] );
	}

	/**
	 * Retrieve customers data from the database
	 *
	 * @param int $per_page
	 * @param int $page_number
	 *
	 * @return mixed
	 */
	public static function get_old_device( ) {
		global $wpdb;
        $sql = "SELECT * FROM {$wpdb->prefix}myownsms_devices WHERE state = 02";
        $result = $wpdb->get_results( $sql, 'ARRAY_A' );
        return $result;
	}

	/**
	 * Returns the count of records in the database.
	 *
	 * @return null|string
	 */
	public static function record_count() {
		global $wpdb;
		$sql = "SELECT COUNT(*) FROM {$wpdb->prefix}myownsms_devices WHERE state = 02";
        return $wpdb->get_var( $sql );
	}

	/** Text displayed when no customer data is available */
	public function no_items() {
		_e( 'No device avaliable.', 'wpmyownsms' );
	}

	/**
	 * Render a column when no column specific method exist.
	 *
	 * @param array $item
	 * @param string $column_name
	 *
	 * @return mixed
	 */
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
			case 'id_device':
            case 'name_device':
            case 'num_tot_sms':
				return $item[ $column_name ];
			default:
                return $item[ $column_name ];
				//return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}

	/**
	 *  Associative array of columns
	 *
	 * @return array
	 */
	function get_columns() {
		$columns = [
			'id_device' => __('Device ID', 'wpmyownsms'),
            'name_device' => __('Device Name', 'wpmyownsms'),
            'num_tot_sms' => __('Total SMS sent', 'wpmyownsms')
		];
		return $columns;
	}

	/**
	 * Handles data query and filter, sorting, and pagination.
	 */
	public function prepare_items() {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
		$this->process_bulk_action();
		$this->items = self::get_old_device( );
	}

}
