<?php
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WP_List_Table')) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Delete_Own_Customers extends WP_List_Table
{

    /** Class constructor */
    public function __construct()
    {
        parent::__construct([
            'singular' => __('Customer', 'wpmyownsms'), //singular name of the listed records
            'plural' => __('Customers', 'wpmyownsms'), //plural name of the listed records
            'ajax' => false //does this table support ajax?
        ]);
    }

    /**
     * Retrieve customers data from the database
     *
     * @param int $per_page
     * @param int $page_number
     *
     * @return mixed
     */
    public static function get_customers($per_page = 5, $page_number = 1)
    {
        global $wpdb;

        $do_search = MyOwn_Delete_Own_Customers::query_search();

        $sql = "SELECT * " .
            "FROM {$wpdb->prefix}myownsms_import_customers " .
            "WHERE `id_status` = 1 " .
            $do_search;
        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;

        $result = $wpdb->get_results($sql, 'ARRAY_A');
        return $result;
    }

    private static function query_search(){
        global $wpdb;
        $search = filter_input(INPUT_POST, 'd', FILTER_SANITIZE_STRING);
        $search_select = filter_input(INPUT_POST, 'cards', FILTER_SANITIZE_STRING);
        if ($search && $search_select == 'delete_own_customers') {
            $do_search = $wpdb->prepare(" AND ( `alias` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `last_name` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `first_name` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `phone_mobile` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `city` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `language` LIKE '%%%s%%' )", $search);
        } else {
            $do_search = '';
        }
        return $do_search;
    }
    
    /**
     * added a customer record.
     *
     * @param int $id customer ID
     */
    public static function delete_customer($id_customers)
    {
        global $wpdb;
        $wpdb->update(
            "{$wpdb->prefix}myownsms_import_customers", array('id_status' => 0), array('id_customers' => $id_customers), array('%d'), array('%d')
        );
    }

    /**
     * Returns the count of records in the database.
     *
     * @return null|string
     */
    public static function record_count()
    {
        global $wpdb;
        $do_search = MyOwn_Delete_Own_Customers::query_search();
         $sql = "SELECT COUNT(*) " .
            "FROM {$wpdb->prefix}myownsms_import_customers " .
            "WHERE `id_status` = 1 " .
            $do_search;
            
        return $wpdb->get_var($sql);
    }

    /** Text displayed when no customer data is available */
    public function no_items()
    {
        _e('No customers avaliable.', 'wpmyownsms');
    }

    /**
     * Render a column when no column specific method exist.
     *
     * @param array $item
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'alias':
            case 'last_name':
            case 'first_name':
                return $item[$column_name];
            default:
                return $item[$column_name];
        }
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="bulk-delete-own-customer[]" value="%s" />', $item['id_customers']
        );
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_name($item)
    {
        $select_nonce = wp_create_nonce('sp_delete_own_customer');
        $title = '<strong>' . $item['id_customers'] . '</strong>';
        $actions = [
            'delete' => sprintf('<a href="?page=%s&cards=delete_own_customers&action=%s&id_customers=%s&_wpnonce=%s&tab=import">Delete</a>', esc_attr($_REQUEST['page']), 'delete_own', absint($item['id_customers']), $select_nonce)
        ];

        return $title . $this->row_actions($actions);
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_id_customers($item)
    {
        $select_nonce = wp_create_nonce('sp_delete_own_customer');
        $title = '<strong>' . $item['id_customers'] . '</strong>';
        $actions = [
            'delete' => sprintf('<a href="?page=%s&cards=delete_own_customers&action=%s&id_customers=%s&_wpnonce=%s&tab=import">Delete</a>', esc_attr($_REQUEST['page']), 'delete_own', absint($item['id_customers']), $select_nonce)
        ];

        return $title . $this->row_actions($actions);
    }

    /**
     *  Associative array of columns
     *
     * @return array
     */
    function get_columns()
    {
        $columns = [
            'cb' => '<input type="checkbox" />',
            'id_customers' => __('ID', 'wpmyownsms'),
            'alias' => __('Alias', 'wpmyownsms'),
            'first_name' => __('First Name', 'wpmyownsms'),
            'last_name' => __('Last Name', 'wpmyownsms'),
            'city' => __('City', 'wpmyownsms'),
            'language' => __('Language', 'wpmyownsms'),
            'phone_mobile' => __('Phone', 'wpmyownsms')
        ];
        return $columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions()
    {
        $actions = [
            'bulk-delete-own-customer' => __('Delete', 'wpmyownsms')
        ];
        return $actions;
    }

    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items()
    {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();
        $per_page = $this->get_items_per_page('customers_per_page', 5);
        $current_page = $this->get_pagenum();
        $total_items = self::record_count();
        $this->items = self::get_customers($per_page, $current_page);
        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ]);
    }

    public function process_bulk_action()
    {
        if (myown_getQueryValue('cards') == 'delete_own_customers') {
            if (isset($_POST['_wpnonce']) && !empty($_POST['_wpnonce'])) {
                $nonce = filter_input(INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING);
                $action = 'bulk-' . $this->_args['plural'];
                if (!wp_verify_nonce($nonce, $action))
                    wp_die('Nope! Security check failed!');
            }
            $action = $this->current_action();
            switch ($action) {
                case 'delete_own':
                    self::delete_customer(absint($_GET['id_customers']));
                    wp_redirect(esc_url_raw('?page=myownsms_plg_configuration&tab=import'));
                    break;
                case 'bulk-delete-own-customer':
                    $delete_ids = esc_sql($_POST['bulk-delete-own-customer']);
                    foreach ($delete_ids as $id) {
                        self::delete_customer($id);
                    }
                    wp_redirect(esc_url_raw(add_query_arg()));
                    break;
                default:
                    break;
            }
        }
        return;
    }
}
