<?php
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('WP_List_Table')) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class MyOwn_Select_Own_Customers extends WP_List_Table
{

    /** Class constructor */
    public function __construct()
    {
        parent::__construct([
            'singular' => __('Customer', 'wpmyownsms'), //singular name of the listed records
            'plural' => __('Customers', 'wpmyownsms'), //plural name of the listed records
            'ajax' => false //does this table support ajax?
        ]);
    }

    /**
     * Retrieve customers data from the database
     *
     * @param int $per_page
     * @param int $page_number
     *
     * @return mixed
     */
    public static function get_customers($per_page = 5, $page_number = 1)
    {
        global $wpdb;

       $do_search = MyOwn_Select_Own_Customers::query_search();

        $sql = "SELECT * " .
            "FROM {$wpdb->prefix}myownsms_import_customers " .
            "WHERE `id_status` = 0 AND " .
            '`phone_mobile` <> ""' .
            $do_search;

        $sql .= " LIMIT $per_page";
        $sql .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;
        $result = $wpdb->get_results($sql, 'ARRAY_A');
        return $result;
    }
    
    private static function query_search(){
        global $wpdb;
        $search = filter_input(INPUT_POST, 's', FILTER_SANITIZE_STRING);
        $search_select = filter_input(INPUT_POST, 'cards', FILTER_SANITIZE_STRING);
        if ($search && $search_select == 'select_own_customers') {
            $do_search = $wpdb->prepare(" AND ( `alias` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `last_name` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `first_name` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `phone_mobile` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `city` LIKE '%%%s%%' ", $search);
            $do_search .= " OR " . $wpdb->prepare(" `language` LIKE '%%%s%%' )", $search);
        } else {
            $do_search = '';
        }
        return $do_search;
    }

    /**
     * added a customer record.
     *
     * @param int $id customer ID
     */
    public static function added_customer($id_customers)
    {
        global $wpdb;
        $wpdb->update(
            "{$wpdb->prefix}myownsms_import_customers", array('id_status' => 1), array('id_customers' => $id_customers), array('%d'), array('%d')
        );
        $wpdb->show_errors();
    }

    /**
     * remove a customer record.
     *
     * @param int $id customer ID
     */
    public static function remove_customer($id_customers)
    {
        global $wpdb;
        $wpdb->delete(
            "{$wpdb->prefix}myownsms_import_customers", array('id_customers' => $id_customers), array('%d')
        );
        $wpdb->show_errors();
    }

    /**
     * Returns the count of records in the database.
     *
     * @return null|string
     */
    public static function record_count()
    {
        global $wpdb;
        $do_search = MyOwn_Select_Own_Customers::query_search();
        $sql = "SELECT COUNT(*) " .
            "FROM {$wpdb->prefix}myownsms_import_customers " .
            "WHERE `id_status` = 0 AND " .
            '`phone_mobile` <> ""' .
            $do_search;
        return $wpdb->get_var($sql);
    }

    /** Text displayed when no customer data is available */
    public function no_items()
    {
        _e('No customers avaliable.', 'wpmyownsms');
    }

    /**
     * Render a column when no column specific method exist.
     *
     * @param array $item
     * @param string $column_name
     *
     * @return mixed
     */
    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'alias':
            case 'last_name':
            case 'first_name':
                return $item[$column_name];
            default:
                return $item[$column_name];
            //return print_r( $item, true ); //Show the whole array for troubleshooting purposes
        }
    }

    /**
     * Render the bulk edit checkbox
     *
     * @param array $item
     *
     * @return string
     */
    function column_cb($item)
    {
        return sprintf(
            '<input type="checkbox" name="bulk-select-own-customer[]" value="%s" />', $item['id_customers']
        );
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_name($item)
    {
        $select_nonce = wp_create_nonce('sp_select_own_customer');
        $title = '<strong>' . $item['id_customers'] . '</strong>';
        $actions = [
            'select' => sprintf('<a href="?page=%s&cards=select_own_customers&action=%s&id_customers=%s&_wpnonce=%s&tab=import">Select</a>', esc_attr($_REQUEST['page']), 'select_own', absint($item['id_customers']), $select_nonce),
            'remove' => sprintf('<a href="?page=%s&cards=select_own_customers&action=%s&id_customers=%s&_wpnonce=%s&tab=import">Remove</a>', esc_attr($_REQUEST['page']), 'remove_own', absint($item['id_customers']), $select_nonce),
        ];

        return $title . $this->row_actions($actions);
    }

    /**
     * Method for name column
     *
     * @param array $item an array of DB data
     *
     * @return string
     */
    function column_id_customers($item)
    {
        $select_nonce = wp_create_nonce('sp_select_own_customer');
        $title = '<strong>' . $item['id_customers'] . '</strong>';
        $actions = [
            'select' => sprintf('<a href="?page=%s&cards=select_own_customers&action=%s&id_customers=%s&_wpnonce=%s&tab=import">Select</a>', esc_attr($_REQUEST['page']), 'select_own', absint($item['id_customers']), $select_nonce),
            'remove' => sprintf('<a href="?page=%s&cards=select_own_customers&action=%s&id_customers=%s&_wpnonce=%s&tab=import">Remove</a>', esc_attr($_REQUEST['page']), 'remove_own', absint($item['id_customers']), $select_nonce),
        ];

        return $title . $this->row_actions($actions);
    }

    /**
     *  Associative array of columns
     *
     * @return array
     */
    function get_columns()
    {
        $columns = [
            'cb' => '<input type="checkbox" />',
            'id_customers' => __('ID', 'wpmyownsms'),
            'alias' => __('Alias', 'wpmyownsms'),
            'first_name' => __('First Name', 'wpmyownsms'),
            'last_name' => __('Last Name', 'wpmyownsms'),
            'city' => __('City', 'wpmyownsms'),
            'language' => __('Language', 'wpmyownsms'),
            'phone_mobile' => __('Phone', 'wpmyownsms')
        ];
        return $columns;
    }

    /**
     * Returns an associative array containing the bulk action
     *
     * @return array
     */
    public function get_bulk_actions()
    {
        $actions = [
            'bulk-select-own-customer' => __('Select', 'wpmyownsms'),
            'bulk-remove-own-customer' => __('Remove', 'wpmyownsms'),
        ];
        return $actions;
    }

    /**
     * Handles data query and filter, sorting, and pagination.
     */
    public function prepare_items()
    {
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = array();
        $this->_column_headers = array($columns, $hidden, $sortable);
        $this->process_bulk_action();
        $per_page = $this->get_items_per_page('customers_per_page', 5);
        $current_page = $this->get_pagenum();
        $total_items = self::record_count();
        $this->items = self::get_customers($per_page, $current_page);
        $this->set_pagination_args([
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page)
        ]);
    }

    public function process_bulk_action()
    {
        if (myown_getQueryValue('cards') == 'select_own_customers') {
            if (isset($_POST['_wpnonce']) && !empty($_POST['_wpnonce'])) {
                $nonce = filter_input(INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING);
                $action = 'bulk-' . $this->_args['plural'];
                if (!wp_verify_nonce($nonce, $action))
                    wp_die('Nope! Security check failed! ' . $action);
            }
            $action = $this->current_action();
            switch ($action) {
                case 'select_own':
                    self::added_customer(absint($_GET['id_customers']));
                    wp_redirect(esc_url_raw('?page=myownsms_plg_configuration&tab=import'));
                    break;
                case 'remove_own':
                    self::remove_customer(absint($_GET['id_customers']));
                    wp_redirect(esc_url_raw('?page=myownsms_plg_configuration&tab=import'));
                    break;
                case 'bulk-select-own-customer':
                    $delete_ids = esc_sql($_POST['bulk-select-own-customer']);
                    foreach ($delete_ids as $id) {
                        self::added_customer(absint($id));
                    }
                    wp_redirect(esc_url_raw(add_query_arg()));
                    break;
                case 'bulk-remove-own-customer':
                    $delete_ids = esc_sql($_POST['bulk-select-own-customer']);
                    foreach ($delete_ids as $id) {
                        self::remove_customer(absint($id));
                    }
                    wp_redirect( esc_url_raw(add_query_arg()) );
                default:
                    break;
            }
        }
        return;
    }

    /**
     * Display the pagination.
     *
     * @since 3.1.0
     *
     * @param string $which
     */
    protected function pagination($which)
    {
        if (empty($this->_pagination_args)) {
            return;
        }
        $total_items = $this->_pagination_args['total_items'];
        $total_pages = $this->_pagination_args['total_pages'];
        $infinite_scroll = false;
        if (isset($this->_pagination_args['infinite_scroll'])) {
            $infinite_scroll = $this->_pagination_args['infinite_scroll'];
        }
        if ('top' === $which && $total_pages > 1) {
            $this->screen->render_screen_reader_content('heading_pagination');
        }
        $output = '<span class="displaying-num">' . sprintf(_n('%s item', '%s items', $total_items), number_format_i18n($total_items)) . '</span>';
        $current = $this->get_pagenum();
        $removable_query_args = wp_removable_query_args();
        $current_url = set_url_scheme('http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']);
        $current_url = remove_query_arg($removable_query_args, $current_url);
        $page_links = array();
        $total_pages_before = '<span class="paging-input">';
        $total_pages_after = '</span></span>';
        $disable_first = $disable_last = $disable_prev = $disable_next = false;
        if ($current == 1) {
            $disable_first = true;
            $disable_prev = true;
        }
        if ($current == 2) {
            $disable_first = true;
        }
        if ($current == $total_pages) {
            $disable_last = true;
            $disable_next = true;
        }
        if ($current == $total_pages - 1) {
            $disable_last = true;
        }
        if ($disable_first) {
            $page_links[] = '<span class="tablenav-pages-navspan" aria-hidden="true">&laquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='first-page' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>", esc_url(remove_query_arg('paged_select', $current_url)), __('First page'), '&laquo;'
            );
        }
        if ($disable_prev) {
            $page_links[] = '<span class="tablenav-pages-navspan" aria-hidden="true">&lsaquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='prev-page' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>", esc_url(add_query_arg('paged_select', max(1, $current - 1), $current_url)), __('Previous page'), '&lsaquo;'
            );
        }
        if ('bottom' === $which) {
            $html_current_page = $current;
            $total_pages_before = '<span class="screen-reader-text">' . __('Current Page') . '</span><span id="table-paging" class="paging-input"><span class="tablenav-paging-text">';
        } else {
            $html_current_page = sprintf(
                "%s<input class='current-page' id='current-page-selector' type='text' name='paged_select' value='%s' size='%d' aria-describedby='table-paging' /><span class='tablenav-paging-text'>", '<label for="current-page-selector" class="screen-reader-text">' . __('Current Page') . '</label>', $current, strlen($total_pages)
            );
        }
        $html_total_pages = sprintf("<span class='total-pages'>%s</span>", number_format_i18n($total_pages));
        $page_links[] = $total_pages_before . sprintf(_x('%1$s of %2$s', 'paging'), $html_current_page, $html_total_pages) . $total_pages_after;
        if ($disable_next) {
            $page_links[] = '<span class="tablenav-pages-navspan" aria-hidden="true">&rsaquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='next-page' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>", esc_url(add_query_arg('paged_select', min($total_pages, $current + 1), $current_url)), __('Next page'), '&rsaquo;'
            );
        }
        if ($disable_last) {
            $page_links[] = '<span class="tablenav-pages-navspan" aria-hidden="true">&raquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='last-page' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>", esc_url(add_query_arg('paged_select', $total_pages, $current_url)), __('Last page'), '&raquo;'
            );
        }
        $pagination_links_class = 'pagination-links';
        if (!empty($infinite_scroll)) {
            $pagination_links_class .= ' hide-if-js';
        }
        $output .= "\n<span class='$pagination_links_class'>" . join("\n", $page_links) . '</span>';
        if ($total_pages) {
            $page_class = $total_pages < 2 ? ' one-page' : '';
        } else {
            $page_class = ' no-pages';
        }
        $this->_pagination = "<div class='tablenav-pages{$page_class}'>$output</div>";
        echo $this->_pagination;
    }

    /**
     * Get the current page number
     *
     * @since 3.1.0
     *
     * @return int
     */
    public function get_pagenum()
    {
        $pagenum = isset($_REQUEST['paged_select']) ? absint($_REQUEST['paged_select']) : 0;
        if (isset($this->_pagination_args['total_pages']) && $pagenum > $this->_pagination_args['total_pages']) {
            $pagenum = $this->_pagination_args['total_pages'];
        }
        return max(1, $pagenum);
    }
}
